@@ -12,6 +12,7 @@ from functools import lru_cache
 from typing import Any, List, Dict, Iterable, Union, Optional, TextIO
 from .jc_types import TimeStampFormatType
 
+CLI_QUIET = False
 
 def _asciify(string: str) -> str:
     """
@@ -62,6 +63,9 @@ def warning_message(message_lines: List[str]) -> None:
 
         None - just prints output to STDERR
     """
+    if CLI_QUIET:
+        return
+
     # this is for backwards compatibility with existing custom parsers
     if isinstance(message_lines, str):
         message_lines = [message_lines]
@@ -206,7 +210,7 @@ def remove_quotes(data: str) -> str:
 
 
 def normalize_key(data: str) -> str:
-    """
+    r"""
     Normalize a key name by shifting to lower-case and converting special
     characters to underscores.
 
@@ -225,7 +229,7 @@ def normalize_key(data: str) -> str:
 
         string
     """
-    special = '''!"#$%&'()*+,-./:;<=>?@[\]^`{|}~ '''
+    special = r'''!"#$%&'()*+,-./:;<=>?@[\]^`{|}~ '''
     initial_underscore = False
     data = data.strip().lower()
 
@@ -397,6 +401,9 @@ def convert_size_to_int(size: str, binary: bool = False) -> Optional[int]:
         >>> convert_size_to_int('1.5 GB', binary=True)
         1610612736
     """
+    # normalize input by removing commas
+    size = size.replace(',', '')
+
     def tokenize(text: str) -> List[str]:
         tokenized_input: List = []
         for token in re.split(r'(\d+(?:\.\d+)?)', text):
